Interface overview
======================

EveryBeam is primarily written in :code:`C++`. In case EveryBeam was compiled with :code:`BUILD_WITH_PYTHON=ON`
Python bindings are generated to interface the EveryBeam API from within Python. See below for the documentation of the
:code:`C++` and the :code:`Python` interface.

